@@ -1,5 +1,5 @@
 #
-# $Id: Tcp.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Tcp.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # client::tcp Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable socket netcat) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -59,7 +59,7 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
-         rtimeout => $self->global->rtimeout,
+         rtimeout => defined($self->global) && $self->global->rtimeout || 3,
       },
    };
 }
@@ -73,8 +73,6 @@ sub connect {
    $self->brik_help_run_undef_arg('connect', $host) or return;
    $self->brik_help_run_undef_arg('connect', $port) or return;
 
-   my $context = $self->context;
-
    my $mod = $self->use_ipv6 ? 'IO::Socket::INET6' : 'IO::Socket::INET';
 
    my $socket = $mod->new(
@@ -276,7 +274,7 @@ sub read {
          return $self->log->error("read: sysread failed with error [$!]");
       }
       elsif ($ret == 0) { # EOF
-         $self->debug && $self->log->debug("read: eof");
+         $self->log->debug("read: eof");
          $self->eof(1);
          $eof++;
          last;
@@ -284,9 +282,9 @@ sub read {
       elsif ($ret > 0) { # Read stuff
          $read++;
          $data .= $buf;
-         $self->debug && $self->log->debug("read: stuff len[$ret]");
+         $self->log->debug("read: stuff len[$ret]");
          if ($ret == $chunk) {
-            $self->debug && $self->log->debug("read: AGAIN");
+            $self->log->debug("read: AGAIN");
             goto AGAIN;
          }
          last;
@@ -374,7 +372,7 @@ Metabrik::Client::Tcp - client::tcp Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
