@@ -1,5 +1,5 @@
 #
-# $Id: Aes.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Aes.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # crypto::aes Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -65,7 +65,7 @@ sub decrypt {
 
    #my $decrypted = $cipher->decrypt_hex($data);
 
-   $self->debug && $self->log->debug("echo \"$data\" | openssl enc -d -a -aes-128-cbc");
+   $self->log->debug("echo \"$data\" | openssl enc -d -a -aes-128-cbc");
 
    # Will only return hex decoded data
    my $decrypted = `echo "$data" | openssl enc -d -a -aes-128-cbc`;
@@ -83,7 +83,7 @@ Metabrik::Crypto::Aes - crypto::aes Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
