@@ -1,5 +1,5 @@
 #
-# $Id: Jpg.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Jpg.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # image::jpg Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable jpeg) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -42,7 +42,7 @@ sub info {
    my $info = {};
    for my $this (@$out) {
       my ($key, $val) = $this =~ /^(.*?)\s+:\s+(.*)$/;
-      $self->debug && $self->log->debug("info: key [$key] val [$val]");
+      $self->log->debug("info: key [$key] val [$val]");
       $key = lc($key);
       $key =~ s/\s+/_/g;
       $info->{$key} = $val;
@@ -61,7 +61,7 @@ Metabrik::Image::Jpg - image::jpg Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
