@@ -1,5 +1,5 @@
 #
-# $Id: Dns.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Dns.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # server::dns Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -105,7 +105,7 @@ sub start {
       SERVER => {
          address => $hostname,
          port => $port,
-         verbose => $self->debug,
+         verbose => $self->log->level > 2 ? 1 : 0,
          truncate => 1,           # truncate too big 
          timeout => 5,            # seconds
       },
@@ -140,7 +140,7 @@ Metabrik::Server::Dns - server::dns Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
