@@ -1,5 +1,5 @@
 #
-# $Id: Tor.pm,v f6ad8c136b19 2017/01/01 10:13:54 gomor $
+# $Id: Tor.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # server::tor Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command Metabrik::System::Package);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f6ad8c136b19 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -63,7 +63,7 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
-         user => $self->global->username,
+         user => defined($self->global) && $self->global->username || 'username',
       },
    };
 }
@@ -99,6 +99,7 @@ sub generate_conf {
 DataDirectory $datadir
 PidFile $datadir/$pidfile
 RunAsDaemon 1
+ClientOnly 1
 User $user
 
 ControlSocket $datadir/control
@@ -110,7 +111,6 @@ CookieAuthFile $datadir/control.authcookie
 
 Log notice file $datadir/tor.log
 
-ClientOnly 1
 TransPort $tor_port
 TransListenAddress $tor_listen
 DNSPort $dns_port
@@ -210,7 +210,7 @@ Metabrik::Server::Tor - server::tor Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
