@@ -1,5 +1,5 @@
 #
-# $Id: Command.pm,v f421cd03e192 2017/08/26 14:56:55 gomor $
+# $Id: Command.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # shell::command Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f421cd03e192 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(exec execute) ],
       attributes => {
          as_array => [ qw(0|1) ],
@@ -134,23 +134,24 @@ sub system {
 
    my $r = CORE::system($command);
 
-   $self->debug && $self->log->debug("system: command returned code [$r] with status [$?]");
+   $self->log->debug("system: command returned code [$r] with status [$?]");
 
    if (! $self->ignore_error && $? != 0) {
       $self->log->verbose("system: exit code[$?]");
       # Failure, we return the program exit code
-      $self->debug && $self->log->debug("system: program exit code [$?]");
+      $self->log->debug("system: program exit code [$?]");
       return $?;
    }
 
-   $self->debug && $self->log->debug("system: program exit with success");
+   $self->log->debug("system: program exit with success");
 
    # Program succeeded, we only return full path to output file, 
    # maybe the caller will have some optimization to not process ths full 
    # file content afterwards.
    if ($self->capture_system) {
-      my $pwd = $self->shell->full_pwd;
-      my $homedir = $self->global->homedir;
+      my $pwd = defined($self->shell) && $self->shell->full_pwd || '/tmp';
+      my $homedir = defined($self->global) && $self->global->homedir
+         || defined($ENV{HOME}) && $ENV{HOME} || '/tmp';
       $pwd =~ s{^~}{$homedir};
       return $pwd.'/'.$output_file;
    }
@@ -401,7 +402,7 @@ Metabrik::Shell::Command - shell::command Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
