@@ -1,5 +1,5 @@
 #
-# $Id: Syslog.pm,v ce0abe6b7256 2017/05/23 06:22:59 gomor $
+# $Id: Syslog.pm,v 6fa51436f298 2018/01/12 09:27:33 gomor $
 #
 # string::syslog Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: ce0abe6b7256 $',
+      revision => '$Revision: 6fa51436f298 $',
       tags => [ qw(unstable) ],
       author => 'GomoR <GomoR[at]metabrik.org>',
       license => 'http://opensource.org/licenses/BSD-3-Clause',
@@ -41,7 +41,7 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
-         hostname => $self->global->hostname,
+         hostname => defined($self->global) && $self->global->hostname || 'hostname',
       },
    };
 }
@@ -165,7 +165,7 @@ Metabrik::String::Syslog - string::syslog Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2017, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2018, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
